@@ -19,4 +19,16 @@ def test_content_keys():
     assert db.get('ASD02400000_12') is not None
     assert db.get('ASD17430000_1') is not None
     with pytest.raises(KeyError):
-        db.get('ASDNOTEXISTING_KEY') is not None
\ No newline at end of file
+        db.get('ASDNOTEXISTING_KEY') is not None
+
+def test_pdbs_included():
+    db = AsdDB(DIR_TEST_DATA + "/asd")
+    protein = db.get('ASD02400000_12')
+    assert len(protein.pdbs) == 4
+    assert [pdb.id for pdb in protein.pdbs ] == ['3TNP','4X6Q','3TNQ','4WBB']
+    
+def test_ptms_included():
+    db = AsdDB(DIR_TEST_DATA + "/asd")
+    protein = db.get('ASD02400000_12')
+    assert len(protein.ptms) == 4
+    assert [ptm.position for ptm in protein.ptms] == [85, 2, 83, 112]
\ No newline at end of file
